=======
History
=======

1.2.8 (2025-04-28)
-------------------
* Fixed bug from merge conflict

1.2.7 (2025-04-24)
-------------------
* Added support for no time data in CV
* Fixed bug in CV for no time data and CLI

1.2.6 (2023-12-16)
-------------------
* Fixed bug in CP for differential capacity plot
* Handled None and Infinite values in CP plots
* Fixed index in CV


1.2.5 (2023-12-15)
-------------------
* Fixed bug in CA for zero reaction rate constant
* Fixed bug in index handling for CA
* Fixed bug in plot ticks

1.2.3 (2023-12-11)
-------------------
* Include python 3.8

1.2.1 (2023-12-11)
-------------------
* Added Ciclic Voltammetry to the functions
* CA, CP and CV can be used with multiple plots to chose from
* New and Imrpoved GUI
* Fixed saving bug

1.1.0 (2023-08-07)
-------------------
* Fixes issue with mismatch array length when positive imaginary data is given

0.11.0 (2022-10-16)
-------------------

* Fixed bugs concering the package installation.
* Improved the documentation.
* Imrpoved the file structure.
* madap_gui and madap_cli are now in the same package and can be used as standalone scripts/commands.

0.10.0 (2022-10-03)
-------------------

* Updated support of the python versions

0.9.0 (2022-10-02)
------------------

* Update documentation

0.8.0 (2022-10-02)
------------------

* First release on PyPI.
